@@ -191,7 +191,7 @@ class KafkaClient(BaseClient):
         self,
         *,
         Name: str,
-        ServerProperties: Union[bytes, IO[bytes], StreamingBody],
+        ServerProperties: Union[str, bytes, IO[Any], StreamingBody],
         Description: str = ...,
         KafkaVersions: Sequence[str] = ...
     ) -> CreateConfigurationResponseTypeDef:
@@ -483,7 +483,7 @@ class KafkaClient(BaseClient):
         self,
         *,
         Arn: str,
-        ServerProperties: Union[bytes, IO[bytes], StreamingBody],
+        ServerProperties: Union[str, bytes, IO[Any], StreamingBody],
         Description: str = ...
     ) -> UpdateConfigurationResponseTypeDef:
         """
