@@ -13,10 +13,9 @@ Usage::
 """
 import sys
 from datetime import datetime
-from typing import IO, Dict, List, Mapping, Sequence, Union
+from typing import IO, Any, Dict, List, Mapping, Sequence, Union
 
 from botocore.response import StreamingBody
-from typing_extensions import NotRequired
 
 from .literals import (
     ClientBrokerType,
@@ -531,7 +530,7 @@ _RequiredCreateConfigurationRequestRequestTypeDef = TypedDict(
     "_RequiredCreateConfigurationRequestRequestTypeDef",
     {
         "Name": str,
-        "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
+        "ServerProperties": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 _OptionalCreateConfigurationRequestRequestTypeDef = TypedDict(
@@ -1620,7 +1619,7 @@ _RequiredUpdateConfigurationRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateConfigurationRequestRequestTypeDef",
     {
         "Arn": str,
-        "ServerProperties": Union[bytes, IO[bytes], StreamingBody],
+        "ServerProperties": Union[str, bytes, IO[Any], StreamingBody],
     },
 )
 _OptionalUpdateConfigurationRequestRequestTypeDef = TypedDict(
